@@ -11,11 +11,13 @@ import tensorflow as tf
 
 
 edge_index = [
-    [0, 0, 0, 0, 1, 1, 4, 6],
-    [0, 2, 4, 6, 2, 3, 6, 8]
+    [0, 0, 0, 0, 0, 1, 1, 4, 6],
+    [0, 0, 2, 4, 6, 2, 3, 6, 8]
 ]
 
-adj = SparseMatrix(edge_index)
+adj = SparseMatrix(edge_index, merge=True)
+print(adj.to_dense())
+asdfasdf
 # print(adj)
 # print("==========")
 # print(adj.to_sparse_tensor())
